@@ -24,7 +24,7 @@ from docutils.statemachine import ViewList
 import sphinx
 from sphinx.locale import _
 from sphinx.util.i18n import search_image_for_language
-from sphinx.util.osutil import ensuredir, ENOENT
+from sphinx.util.osutil import ensuredir
 from sphinx.util import logging
 from .exceptions import MermaidError
 from .autoclassdiag import class_diagram
@@ -173,9 +173,7 @@ def render_mm(self, code, options, _fmt, prefix='mermaid'):
 
     try:
         p = Popen(mm_args, shell=mermaid_cmd_shell, stdout=PIPE, stdin=PIPE, stderr=PIPE)
-    except OSError as err:
-        if err.errno != ENOENT:   # No such file or directory
-            raise
+    except FileNotFoundError:
         logger.warning('command %r cannot be run (needed for mermaid '
                        'output), check the mermaid_cmd setting' % mermaid_cmd)
         return None, None
@@ -195,11 +193,6 @@ def render_mm(self, code, options, _fmt, prefix='mermaid'):
 
 def _render_mm_html_raw(self, node, code, options, prefix='mermaid',
                    imgcls=None, alt=None):
-
-    init_js = self.builder.config.mermaid_init_js
-    if init_js not in self.body:
-        self.body.append(init_js)
-
     if 'align' in node:
         tag_template = """<div align="{align}" class="mermaid align-{align}">
             {code}
@@ -358,6 +351,9 @@ def install_js(app, *args):
     if _mermaid_js_url:
         app.add_js_file(_mermaid_js_url)
 
+    if app.config.mermaid_init_js:
+        app.add_js_file(None, body=app.config.mermaid_init_js)
+
 
 def setup(app):
     app.add_node(mermaid,
@@ -377,7 +373,7 @@ def setup(app):
     app.add_config_value('mermaid_verbose', False, 'html')
     app.add_config_value('mermaid_sequence_config', False, 'html')
     app.add_config_value('mermaid_version', 'latest', 'html')
-    app.add_config_value('mermaid_init_js', "<script>mermaid.initialize({startOnLoad:true});</script>", 'html')
+    app.add_config_value('mermaid_init_js', "mermaid.initialize({startOnLoad:true});", 'html')
     app.connect('html-page-context', install_js)
 
     return {'version': sphinx.__display_version__, 'parallel_read_safe': True}
